==> ejc-salary-impl-3.0.0-20241017.065649-32-sources.jar: com/ejianc/business/salary/bean/RosterTransferEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人员花名册-异动
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_roster_transfer")
public class RosterTransferEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="start_time")
    private Date startTime; // 起始时间
    @TableField(value="end_time")
    private Date endTime; // 终止时间
    @TableField(value="org_code")
    private String orgCode; // 所在单位code
    @TableField(value="org_name")
    private String orgName; // 所在单位
    @TableField(value="department_code")
    private String departmentCode; // 所在部门code
    @TableField(value="department_name")
    private String departmentName; // 所在部门
    @TableField(value="project_code")
    private String projectCode; // 所在项目code
    @TableField(value="project_name")
    private String projectName; // 所在项目
    @TableField(value="post_code")
    private String postCode; // 任职岗位code
    @TableField(value="post_name")
    private String postName; // 任职岗位
    @TableField(value="sync_day")
    private Long syncDay; // 同步日期
    @TableField(value="hr_id")
    private String hrId; // 人力主键
    @TableField(value="hr_state")
    private Integer hrState; // 人力状态（1：正常，2：删除）
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 身份证号
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getPostCode() {
        return postCode;
    }

    public void setPostCode(String postCode) {
        this.postCode = postCode;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public String getHrId() {
        return hrId;
    }

    public void setHrId(String hrId) {
        this.hrId = hrId;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}

==> ejc-salary-impl-3.0.0-20251110.075415-192-sources.jar: com/ejianc/business/salary/bean/RosterTransferEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人员花名册-异动
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_roster_transfer")
public class RosterTransferEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="start_time")
    private Date startTime; // 起始时间
    @TableField(value="end_time")
    private Date endTime; // 终止时间
    @TableField(value="org_code")
    private String orgCode; // 所在单位code
    @TableField(value="org_name")
    private String orgName; // 所在单位
    @TableField(value="department_code")
    private String departmentCode; // 所在部门code
    @TableField(value="department_name")
    private String departmentName; // 所在部门
    @TableField(value="project_code")
    private String projectCode; // 所在项目code
    @TableField(value="project_name")
    private String projectName; // 所在项目
    @TableField(value="post_code")
    private String postCode; // 任职岗位code
    @TableField(value="post_name")
    private String postName; // 任职岗位
    @TableField(value="sync_day")
    private Long syncDay; // 同步日期
    @TableField(value="hr_id")
    private String hrId; // 人力主键
    @TableField(value="hr_state")
    private Integer hrState; // 人力状态（1：正常，2：删除）
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="old_org_code")
    private String oldOrgCode; // 调动前所在组织
    @TableField(value="old_org_name")
    private String oldOrgName; // 调动前所在组织
    @TableField(value="old_department_code")
    private String oldDepartmentCode; // 调动前所在部门
    @TableField(value="old_department_name")
    private String oldDepartmentName; // 调动前所在部门


    public String getOldOrgCode() {
        return oldOrgCode;
    }

    public void setOldOrgCode(String oldOrgCode) {
        this.oldOrgCode = oldOrgCode;
    }

    public String getOldOrgName() {
        return oldOrgName;
    }

    public void setOldOrgName(String oldOrgName) {
        this.oldOrgName = oldOrgName;
    }

    public String getOldDepartmentCode() {
        return oldDepartmentCode;
    }

    public void setOldDepartmentCode(String oldDepartmentCode) {
        this.oldDepartmentCode = oldDepartmentCode;
    }

    public String getOldDepartmentName() {
        return oldDepartmentName;
    }

    public void setOldDepartmentName(String oldDepartmentName) {
        this.oldDepartmentName = oldDepartmentName;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getPostCode() {
        return postCode;
    }

    public void setPostCode(String postCode) {
        this.postCode = postCode;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public String getHrId() {
        return hrId;
    }

    public void setHrId(String hrId) {
        this.hrId = hrId;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}
